@@ -1,7 +1,7 @@
 import datetime
 from flask import request, redirect
 
-from flaskext.admin import Admin, ModelAdmin, AdminPanel
+from flask_peewee.admin import Admin, ModelAdmin, AdminPanel
 
 from app import app, db
 from auth import auth
